@@ -415,6 +415,8 @@ class Page(ElasticEntity):
         'is_draft': bool,
         'is_sandbox': bool,
         'user_rating': float,
+        'user_pros_count': int,
+        'user_cons_count': int,
         'games_count': int,
         'operator': str,
         'establishedon': DateTimeField,
